#include <xc.h>         /* XC8 Compiler General Include File */
#include <stdint.h>        /* For uint8_t definition */
#include <stdbool.h>       /* For true/false definition */

// CONFIG
#pragma config FOSC = INTOSCIO  // Oscillator Selection bits (INTOSC oscillator: I/O function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN)
#pragma config WDTE = ON        // Watchdog Timer Enable bit (WDT enabled)
#pragma config PWRTE = ON       // Power-up Timer Enable bit (PWRT enabled)
#pragma config MCLRE = ON       // RA5/MCLR/VPP Pin Function Select bit (RA5/MCLR/VPP pin function is MCLR)
#pragma config BOREN = ON       // Brown-out Detect Enable bit (BOD enabled)
#pragma config LVP = ON         // Low-Voltage Programming Enable bit (RB4/PGM pin has PGM function, low-voltage programming enabled)
#pragma config CPD = OFF        // Data EE Memory Code Protection bit (Data memory code protection off)
#pragma config CP = OFF         // Flash Program Memory Code Protection bit (Code protection off)

// the configs will result in 0xFFF4 being written to address 0x2007
/* Microcontroller MIPs (FCY) */
#define SYS_FREQ        500000L // 5MHz
#define FCY             SYS_FREQ/4


/******************************************************************************/
/* User Global Variable Declaration                                           */
/******************************************************************************/


#define dotPeriod (500) // 0.5 sec
#define dashPeriod (dotPeriod*3)
#define relaxTime (dotPeriod)
#define letterSpace (dotPeriod*2)
#define wordSpace (dotPeriod*4)

unsigned char ucharCount = 0;

/******************************************************************************/
/* Main Program                                                               */
/******************************************************************************/

void delay(int ltime){
     //Delay Loop
      unsigned int uintDelayCount = 0;
      while ( uintDelayCount < (20 * ltime) )
      {
	  //Increment the loop counter
	  uintDelayCount++;
      }
}

void di()
{
  //tone(tonePin, buzz);
  PORTA = 0x02;
  delay(dotPeriod);
  //noTone(tonePin);
  PORTA = 0x00;
  delay(relaxTime);
}

void dah()
{
  //tone(tonePin, buzz);
  PORTA = 0x02;
  delay(dashPeriod);
  //noTone(tonePin);
  PORTA = 0x00;
  delay(relaxTime);
}

void playLetter(char x)
{
	switch (x){
		case 'E':
			di(); break;
		case 'T':
			dah(); break;
		case 'A':
			di();dah(); break;
		case 'O':
			dah();dah();dah(); break;
                case 'P':
			di();dah();dah();di(); break;
                case 'D':
			dah();di();di(); break;
		case '1':
			di();dah();dah();dah();dah(); break;
		case 'C':
			dah();di();dah();di(); break;
                case 'F':
			di();di();dah();di(); break;
		case ' ':
			delay(wordSpace);
        }
}  

void main(void)
{
    TRISA = 0x00;

    ucharCount = 0;
    uintDelayCount = 0;

    while(1)
    {
      playLetter('P');
      playLetter('D');
      playLetter('1');
      playLetter('C');
      playLetter('F');
      delay(2500);
    }

}
